==> 0.11.2.tar.gz: test/global_test.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

library omnibus.test.global_test;

import 'dart:async';

import 'package:test/test.dart';
import 'package:omnibus/omnibus.dart';

import 'messages_lib.dart';

/// Counters for the global handlers
int totalEvents = 0;
int totalRequests = 0;

main() {
  test('Test global handlers', () async {
    var bus = new Omnibus();

    // Bind global handlers.
    bus.bindGlobalEventHandler(globalEventHandler);
    bus.bindGlobalRequestHandler(globalRequestHandler);

    // Run some events.
    bus.publishEvent(mMessageForAll('This message is for everyone!'));
    bus.publishEvent(mEmail('Hi!', from: 'a@here.com', to: 'b@here.com'));

    // Run some requests.
    bus.publishRequest(
        mCalculationRequest(1.0, 1.0, CalculationOperator.subtract));
    bus.publishRequest(
        mCalculationRequest(1.0, 1.0, CalculationOperator.multiply));

    // This request goes trough all json_map functions.
    bus.publishRequest(mFakeRequest({
      'message': 'This is fake!',
      'map': {
        '1to3': [1, 2, '3']
      }
    }));

    // Construct request by hand.
    bus.publishRequest(new OmnibusRequest('omnibus.mCustom', {}));

    // Wait for async completion.
    new Future.delayed(new Duration(seconds: 1), () {
      expect(totalEvents, equals(2));
      expect(totalRequests, equals(3));
    });
  });
}

/// Event handler that receives all events.
Future globalEventHandler(OmnibusEvent event) async {
  totalEvents++;
}

/// Request handler that receives all requests.
Future<List<Future<OmnibusResponse>>> globalRequestHandler(
    OmnibusRequest request) async {
  totalRequests++;
  return new List<Future<OmnibusResponse>>()
    ..add(new Future.value(mFakeResponse()));
}

==> 0.11.3.tar.gz: test/global_test.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

library omnibus.test.global_test;

import 'dart:async';

import 'package:test/test.dart';
import 'package:omnibus/omnibus.dart';

import 'messages_lib.dart' as v0;

/// Counters for the global handlers
int totalEvents = 0;
int totalRequests = 0;

void main() {
  test('Test global handlers', () async {
    var bus = new Omnibus();

    // Bind global handlers.
    bus.bindGlobalEventHandler(globalEventHandler);
    bus.bindGlobalRequestHandler(globalRequestHandler);

    // Run some events.
    bus.publishEvent(new v0.MessageForAll('This message is for everyone!'));
    bus.publishEvent(new v0.Email('Hi!', from: 'a@here.com', to: 'b@here.com'));

    // Run some requests.
    bus.publishRequest(
        new v0.CalculationRequest(1.0, 1.0, v0.CalculationOperator.subtract));
    bus.publishRequest(
        new v0.CalculationRequest(1.0, 1.0, v0.CalculationOperator.multiply));

    // This request goes through all json_map functions.
    bus.publishRequest(new v0.FakeRequest({
      'numbers': [0, 1, 2, 3]
    }, {
      'booleans': [true, false, true]
    }));

    // Construct request by hand.
    bus.publishRequest(new OmnibusRequest('omnibus.v0.Custom', {}));

    // Wait for async completion.
    new Future.delayed(new Duration(seconds: 1), () {
      expect(totalEvents, equals(2));
      expect(totalRequests, equals(3));
    });
  });
}

/// Event handler that receives all events.
Future<Null> globalEventHandler(OmnibusEvent event) async {
  totalEvents++;
}

/// Request handler that receives all requests.
Future<List<Future<OmnibusResponse>>> globalRequestHandler(
    OmnibusRequest request) async {
  totalRequests++;
  return new List<Future<OmnibusResponse>>()
    ..add(new Future.value(new v0.FakeResponse()));
}
